@@ -1,6 +1,3 @@
-from .json_object import JsonObject, JsonList
-
-
 def _use_self(funct):
     from inspect import signature, _empty
     s = signature(funct)
@@ -10,7 +7,7 @@ def _use_self(funct):
 def json_force_parameter_type_function(funct):
     def decorated(*args, **kwargs):
         from inspect import signature
-        from json_cpp.json_object import JsonObject
+        from .json_object import JsonObject, JsonList
         if args:
             args = list(args)
         parameters = signature(funct).parameters
@@ -36,7 +33,7 @@ def json_force_parameter_type_function(funct):
 def json_force_parameter_type_method(funct):
     def decorated(self, *args, **kwargs):
         from inspect import signature
-        from json_cpp.json_object import JsonObject
+        from .json_object import JsonObject, JsonList
         if args:
             args = list(args)
         parameters = signature(funct).parameters
@@ -68,6 +65,7 @@ def json_force_parameter_type(funct):
 
 def json_parameters_function(funct):
     def decorated(json_object):
+        from .json_object import JsonObject
         if not isinstance(json_object, JsonObject):
             raise TypeError("Parameter must be JsonObject instance")
         p = json_object.to_dict()
@@ -77,6 +75,7 @@ def json_parameters_function(funct):
 
 def json_parameters_method(funct):
     def decorated(self, json_object):
+        from .json_object import JsonObject
         if not isinstance(json_object, JsonObject):
             raise TypeError("Parameter must be JsonObject instance")
         p = json_object.to_dict()
@@ -91,16 +90,9 @@ def json_parameters(funct):
         return json_parameters_function(funct)
 
 
-def json_parse(funct):
-    if _use_self(funct):
-        def decorated(self, json_string: str):
-            return funct(JsonObject.load())
-
-        return decorated
-
-
 def json_parse(json_object_type=None):
     def decorator(funct):
+        from .json_object import JsonObject
         if _use_self(funct):
             if json_object_type:
                 def decorated(self, json_string: str):
